Module types

Module types 

Enums

Base
Nucleotide encoding (A=0, C=1, G=2, T=3)

Constants

AGC_FILE_MAJOR
Archive file format version
AGC_FILE_MINOR
AGC_VER_BUGFIX
AGC_VER_BUILD
AGC_VER_MAJOR
Version information
AGC_VER_MINOR
CONTIG_SEPARATOR
Contig separator byte in packed-contig mode (0xFF) C++ uses this to pack multiple contigs into a single compressed part

Functions

agc_version
Full version string

Type Aliases

Contig
A contig (genome sequence) represented as a vector of bytes Each byte typically represents a nucleotide base
PackedBlock
A packed/compressed data block